==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/creatures/dialogs_ru.lua <==
dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Посмотри на этих лобстеров...")

dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Они спят по тысями лет... вечный покой...")

dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...и правительство пытается их скрывать.")

dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...ничего не может их разбудить...")

dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Пока мы не пробудим осьминога.")

dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Посмотри, всюду тишина и спокойствие.")

dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Но анемоны двигаются.")

dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")
dialogStr("Может быть, это агония.")

dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Я вижу определённую символичность в этом.")

dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Интересно, эти кораллы нормально растут только в Бермудском Треугольнике.")

dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Знаешь, некоторые виды кораллов умнее рыб?")

dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Осторожнее, многие виды кораллов ядовитые.")

dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a 'coral-soul’?")
dialogStr("Как думаешь, у кораллов есть коралловая душа?")

dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Тебе не кажешься, что кораллы за нами наблюдают?")

dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Интересно, почему кораллы имеют причудливую форму?")

dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")
dialogStr("Это какой-то номер, или что?")

dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")
dialogStr("Ух, это отличный музыкант.")

dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")
dialogStr("Это здорово! Что если мы подвинем его ещё раз?")

dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Ты видел, что выделывал этот лобстер?")

dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("И как танцуют анемоны?")

dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")
dialogStr("Итак, ты знаешь какие есть развлечения на дне океана.")

dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")
dialogStr("Он хорош, не правда ли?")

dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Неплохо для осьминога...")

dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Как думаешь, он знает другие мелодии?")

dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")
dialogStr("Может уже хватит?")

dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")
dialogStr("Меня сейчас вырвет...")

dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")
dialogStr("Я уже сыт по горло...")

dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")
dialogStr("Я сыт по горло этим...")

dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")
dialogStr("Я не могу сдвинуть это тут. Нужно попробовать подойти слева.")

dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")
dialogStr("Что ж, тебе придется идти мимо анемон.")

dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")
dialogStr("Что-то я не предусмотрела...")

dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Мы должны заткнуть эту дыру заранее.")

dialogId("kor-chob-chro", "", "")
dialogStr("")

dialogId("kor-chob-psi", "", "")
dialogStr("")

dialogId("kor-chob-tca", "", "")
dialogStr("")

dialogId("kor-room-music", "", "")
dialogStr("")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/creatures/dialogs_ru.lua <==
dialogId("kor-m-podivej", "font_small", "Look at all these lobsters...")
dialogStr("Посмотри на этих лобстеров...")

dialogId("kor-v-spitu", "font_big", "They sleep for thousands of years... in eternal stillness...")
dialogStr("Они спят по тысями лет... вечный покой...")

dialogId("kor-m-avlada", "font_small", "...and the government tries to cover it up.")
dialogStr("...и правительство пытается их скрывать.")

dialogId("kor-v-nicje", "font_big", "...nothing can wake them up...")
dialogStr("...ничего не может их разбудить...")

dialogId("kor-m-pokud", "font_small", "Unless we activate that octopus.")
dialogStr("Пока мы не пробудим осьминога.")

dialogId("kor-v-podivej", "font_big", "Look, everything here is so still and quiet.")
dialogStr("Посмотри, всюду тишина и спокойствие.")

dialogId("kor-m-vzdyt", "font_small", "But the anemones are moving.")
dialogStr("Но анемоны двигаются.")

dialogId("kor-v-treba", "font_big", "Maybe they’re in the throes of death.")
dialogStr("Может быть, это агония.")

dialogId("kor-v-shledavam", "font_big", "I find a certain symbolism in that.")
dialogStr("Я вижу определённую символичность в этом.")

dialogId("kor-v-bermudy", "font_big", "That’s interesting. This type of coral normally grows only in the Bermuda Triangle.")
dialogStr("Интересно, эти кораллы нормально растут только в Бермудском Треугольнике.")

dialogId("kor-v-inteligentni", "font_big", "Did you know that some types of coral are almost as intelligent as fish?")
dialogStr("Знаешь, некоторые виды кораллов умнее рыб?")

dialogId("kor-v-jedovate", "font_big", "Be careful, most types of coral are poisonous.")
dialogStr("Осторожнее, многие виды кораллов ядовитые.")

dialogId("kor-m-dusi", "font_small", "What do you think, is there such a thing as a ‘coral-soul’?")
dialogStr("Как думаешь, у кораллов есть коралловая душа?")

dialogId("kor-m-pocit", "font_small", "Do you have the feeling that those coral are watching us?")
dialogStr("Тебе не кажешься, что кораллы за нами наблюдают?")

dialogId("kor-m-bizarni", "font_small", "I wonder why the coral have such a bizarre shape.")
dialogStr("Интересно, почему кораллы имеют причудливую форму?")

dialogId("kor-v-juchacka", "font_big", "That was some number, wasn’t it?")
dialogStr("Это какой-то номер, или что?")

dialogId("kor-m-hraje", "font_small", "Yeah, he’s a great player.")
dialogStr("Ух, это отличный музыкант.")

dialogId("kor-v-odvaz", "font_big", "That’s cool. What if we pushed him again?")
dialogStr("Это здорово! Что если мы подвинем его ещё раз?")

dialogId("kor-m-vsimlsis", "font_small", "Did you see what the lobsters were doing?")
dialogStr("Ты видел, что выделывал этот лобстер?")

dialogId("kor-v-avidelas", "font_big", "And how those anemones were dancing?")
dialogStr("И как танцуют анемоны?")

dialogId("kor-m-tovis", "font_small", "Well, you know, it’s not all that much fun down here at the bottom of the ocean.")
dialogStr("Итак, ты знаешь какие есть развлечения на дне океана.")

dialogId("kor-v-vali", "font_big", "He’s good, isn’t he?")
dialogStr("Он хорош, не правда ли?")

dialogId("kor-m-nachob", "font_small", "Not bad for an octopus...")
dialogStr("Неплохо для осьминога...")

dialogId("kor-m-jinou", "font_small", "Do you think he knows any other tune?")
dialogStr("Как думаешь, он знает другие мелодии?")

dialogId("kor-m-neprehani", "font_small", "Don’t you think we’ve had enough already?")
dialogStr("Может уже хватит?")

dialogId("kor-m-lezekrkem", "font_small", "I’m getting sick of it...")
dialogStr("Меня сейчас вырвет...")

dialogId("kor-v-lezekrkem", "font_big", "I’m sick and tired of it...")
dialogStr("Я уже сыт по горло...")

dialogId("kor-v-kostice", "font_big", "I’m fed up to the gills with this.")
dialogStr("Я сыт по горло этим...")

dialogId("kor-v-odsud", "font_big", "I can’t budge this from where I am. I’d have to try to move it from the left side.")
dialogStr("Я не могу сдвинуть это тут. Нужно попробовать подойти слева.")

dialogId("kor-m-budesmuset", "font_small", "Well you’ll have to go that way through those anemones.")
dialogStr("Что ж, тебе придется идти мимо анемон.")

dialogId("kor-m-neniono", "font_small", "That’s not what I had in mind...")
dialogStr("Что-то я не предусмотрела...")

dialogId("kor-m-tudiru", "font_small", "We should have plugged that hole beforehand.")
dialogStr("Мы должны заткнуть эту дыру заранее.")

dialogId("kor-chob-chro", "", "")
dialogStr("")

dialogId("kor-chob-psi", "", "")
dialogStr("")

dialogId("kor-chob-tca", "", "")
dialogStr("")

dialogId("kor-room-music", "", "")
dialogStr("")
